@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.008_001;
 
-our $VERSION = 0.006;
+our $VERSION = 0.008;
 
 use Socket qw/SOCK_RAW/;
 use Time::HiRes 'time';
@@ -12,7 +12,7 @@ use IO::Socket::INET qw/sockaddr_in inet_aton/;
 use List::Util ();
 require Carp;
 
-my $ICMP_PING = 'ccnnnA*';
+my $ICMP_PING = 'ccnnna*';
 
 my $ICMP_ECHOREPLY     = 0;     # Echo Reply
 my $ICMP_DEST_UNREACH  = 3;     # Destination Unreachable
@@ -313,14 +313,22 @@ AnyEvent::Ping - ping hosts with AnyEvent
     use AnyEvent;
     use AnyEvent::Ping;
 
+    my $host  = shift || '4.2.2.2';
+    my $times = shift || 4;
+    my $package_s = shift || 56;
     my $c = AnyEvent->condvar;
 
     my $ping = AnyEvent::Ping->new;
 
-    $ping->ping('google.com', 1, sub {
-        my $result = shift;
-        print "Result: ", $result->[0][0],
-          " in ", $result->[0][1], " seconds\n";
+    print "PING $host $package_s(@{[$package_s+8]}) bytes of data\n";
+    $ping->ping($host, $times, sub {
+        my $results = shift;
+        foreach my $result (@$results) {
+            my $status = $result->[0];
+            my $time   = $result->[1];
+            printf "%s from %s: time=%f ms\n", 
+                $status, $host, $time * 1000;
+        };
         $c->send;
     });
 
@@ -392,10 +400,10 @@ Generates the data to be sent.
 =head3 C<packet_size>
 
 You can set the number of data bytes to be sent, if packet generation function
-is not set. The default is 54, which translates into 64 ICMP data bytes when
+is not set. The default is 56, which translates into 64 ICMP data bytes when
 combined with the 8 bytes of ICMP header data.
 
-    my $ping = AnyEvent::Ping->new(packet_size => 54);
+    my $ping = AnyEvent::Ping->new(packet_size => 56);
 
 Each packet will be generated with generate_data_random() like this:
 
@@ -404,7 +412,12 @@ Each packet will be generated with generate_data_random() like this:
 =head2 C<ping>
 
     $ping->ping($ip, $n => sub {
-        my $result = shift;
+        my $results = shift;
+
+        foreach my $result (@$results){
+            my ($status, $time) = @$result;
+            ...
+        };
     });
 
 Perform a ping of a given $ip address $n times.
@@ -427,6 +440,8 @@ Sergey Zasenko, C<undef@cpan.org>.
 
 Kirill (qsimpleq)
 
+Sebastien Deseille (sdeseille)
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2012-2014, Sergey Zasenko
